Freezes
=======

.. image:: https://secure.travis-ci.org/DotNetAge/freezes.png?branch=master
   :alt: Build Status
   :target: http://travis-ci.org/DotNetAge/freezes

.. image:: https://pypip.in/py_versions/freezes/badge.svg
    :target: https://pypi.python.org/pypi/freezes/
    :alt: Supported Python versions

..  image:: https://pypip.in/status/freezes/badge.svg
    :target: https://pypi.python.org/pypi/freezes/
    :alt: Development Status

.. image:: https://pypip.in/version/freezes/badge.svg
    :target: https://pypi.python.org/pypi/freezes/
    :alt: Latest Version

.. image:: https://pypip.in/license/freezes/badge.svg
    :target: https://pypi.python.org/pypi/freezes/
    :alt: License

Overview
--------

Freezes is a web application to transform plain text or blog to static website. And it can be use as a writing tools with pure markdown and front-end development tools.

Requirements
------------

* Python 2.7
* Works on Linux, Windows, Mac OSX, BSD

Installation
------------

The quick way ::

    $ pip install freezes


For more details see the install section in the documentation:
http://freezes.dotnetage.com/documents/quick-started/


Resources
---------

- `Document <http://freezes.dotnetage.com>`_
- `Issue Tracker <http://github.com/DotNetAge/freezes/issues>`_
- `Code <http://github.com/DotNetAge/freezes/>`_